@@ -53,7 +53,7 @@ import googleapiclient # to install this : pip install --upgrade google-api-pyth
 #  3. The Scope
 
 DEFAULT_SCOPES = {
-    'gmail': ['gmail', 'v1', 'gmail.send'],
+    'gmail': ['gmail', 'v1', 'gmail.compose'],
     'sheets': ['sheets', 'v4', 'spreadsheets'],
     'sheets.readonly': ['sheets', 'v4', 'spreadsheets.readonly'],
     'drive': ['drive', 'v3', 'drive'],
